==> tag-around-text-updater-0.0.1.tgz: package/README.md <==
# Tag-around-text-updater

## Overview

**Tag-around-text-updater** is an open source JavaScript library. It is useful when **highlighting a target text outside tags such as html or xml**. You can insert whatever tags before or after a target text! This library is also available in react as I have add 'babel-preset-react'.


## Example Usage

#### Installation & Usage

There are parameters to be used in the usage below.

``` javascript

var where = '<p></p>\n' +
            '<img style="max-width: 50%;float:none;height: 200px;margin-top : 3%" src="/image/showWorkOrderImg?fileName=12345.png" alt="undefined"/>\n' +
            '<p> abc  777 </p>\n' +
            '<p id="abc" class="def xxx gh" style="text-align:center;">abcabc 555 ' +
			'<p style="color: rgb(127,127,127);">Please email me at gogogo@mail.com </p>&nbsp;</p>\n' +
            '<p><img style="float:none;height: 200px;margin-top : 3%" src="/image/showWorkOrderImg?fileName=123456.png" alt="undefined"/></p>\nabc';

var startTag = '<span style="color:yellow">';
var endTag = '</span>';
var what = 'abc';
var caseSensitive = true;
		      
```

##### Now, let's look at how to use the library.

For ES6 npm users, 'npm install --save tag-around-text-updater'.
(https://www.npmjs.com/package/tag-around-text-updater)

``` javascript

import TagAroundTextUpdater from 'tag-around-text-updater';

let result = new TagAroundTextUpdater().insertByWhat(startTag, endTag, what, where, caseSensitive);
let finalResult = new TagAroundTextUpdater().insertByType(startTag, endTag, 'email', where);

// if it does not work, use below.

let result = TagAroundTextUpdater.insertByWhat(startTag, endTag, what, where, caseSensitive);
let finalResult = TagAroundTextUpdater.insertByType(startTag, endTag, 'email', where);

```

For ES5 users,

``` html

<html>
<body>
	<p id="content"></p>
	<p><button id="loadCat">Lazy load <b>Cat</b></button></p>
	<script src="../dist/tag-around-text-updater.bundle.js"></script>
	<script type="text/javascript">

        var result = TagAroundTextUpdater.insertByWhat(startTag, endTag, what, where, caseSensitive);
        var finalResult = TagAroundTextUpdater.insertByType(startTag, endTag, 'email', result);
        
	</script>
</body>
</html>

```

##### Let's print the variable 'finalResult' above. The word 'abc' and email pattern have been surrounded by the customized tags.

``` html

<p></p>
<img style="max-width: 50%;float:none;height: 200px;margin-top : 3%" src="/image/showWorkOrderImg?fileName=12345.png" alt="undefined"/>
<p> <span style="color:yellow">abc</span>  777 </p>
<p id="abc" class="def xxx gh" style="text-align:center;"><span style="color:yellow">abc</span><span style="color:yellow">abc</span> 555 <p style="color: rgb(127,127,127);">Please email me at <span style="color:yellow">gogogo@mail.com</span> </p>&nbsp;</p>
<p><img style="float:none;height: 200px;margin-top : 3%" src="/image/showWorkOrderImg?fileName=123456.png" alt="undefined"/></p>
<span style="color:yellow">abc</span>
```

## Syntax

``` javascript

/* @params 
*   string : startTag, endTag, what, where
*   boolean : caseSensitive (not necessaray, default : false)
*/
TagAroundTextUpdater.insertByWhat(startTag, endTag, what, where, caseSensitive);

/* @params 
*   string : startTag, endTag, type (only 'integer', 'email' available for the current version), where
*/
TagAroundTextUpdater.insertByType(startTag, endTag, type, where);

```

==> tag-around-text-updater-0.0.2.tgz: package/README.md <==
# Tag-around-text-updater

## Overview

**Tag-around-text-updater** is an open source JavaScript library. It is useful when **highlighting a target text outside tags such as html or xml**. You can insert whatever tags before or after a target text! This library is also available in react as I have add 'babel-preset-react'.


## Example Usage

#### Installation & Usage

There are parameters to be used in the usage below.

``` javascript

var where = '<p></p>\n' +
            '<img style="max-width: 50%;float:none;height: 200px;margin-top : 3%" src="/image/showWorkOrderImg?fileName=12345.png" alt="undefined"/>\n' +
            '<p> abc  777 </p>\n' +
            '<p id="abc" class="def xxx gh" style="text-align:center;">abcabc 555 ' +
			'<p style="color: rgb(127,127,127);">Please email me at gogogo@mail.com </p>&nbsp;</p>\n' +
            '<p><img style="float:none;height: 200px;margin-top : 3%" src="/image/showWorkOrderImg?fileName=123456.png" alt="undefined"/></p>\nabc';

var startTag = '<span style="color:yellow">';
var endTag = '</span>';
var what = 'abc';
var caseSensitive = true;
		      
```

##### Now, let's look at how to use the library.

For ES6 npm users, 'npm install --save tag-around-text-updater'.
(https://www.npmjs.com/package/tag-around-text-updater)

``` javascript

import TagAroundTextUpdater from 'tag-around-text-updater';

let result = new TagAroundTextUpdater().insertByWhat(startTag, endTag, what, where, caseSensitive);
let finalResult = new TagAroundTextUpdater().insertByType(startTag, endTag, 'email', where);

// if it does not work above, use the following usage. (especially for react)

let result = TagAroundTextUpdater.insertByWhat(startTag, endTag, what, where, caseSensitive);
let result2 =  TagAroundTextUpdater.insertByType(startTag, endTag, 'integer', result);
let finalResult = TagAroundTextUpdater.insertByType(startTag, endTag, 'email', result2);

console.log(finalResult);
      
```

For ES5 users,

``` html

<html>
<body>
	<p></p>
	<script src="../dist/tag-around-text-updater.bundle.js"></script>
	<script type="text/javascript">

        var result =  TagAroundTextUpdater.insertByWhat(startTag, endTag, what, where, caseSensitive);
        var result2 =  TagAroundTextUpdater.insertByType(startTag, endTag, 'integer', result);
        var finalResult = TagAroundTextUpdater.insertByType(startTag, endTag, 'email', result2);
        
        console.log(finalResult);
        
	</script>
</body>
</html>

```

##### Let's print the variable 'finalResult' above. The word 'abc', integer or email pattern have been surrounded by the custom tags.

``` html

<p></p>
<img style="max-width: 50%;float:none;height: 200px;margin-top : 3%" src="/image/showWorkOrderImg?fileName=12345.png" alt="undefined"/>
<p> <span style="color:yellow">abc</span>  <span style="color:yellow">777</span> </p>
<p id="abc" class="def xxx gh" style="text-align:center;"><span style="color:yellow">abc</span><span style="color:yellow">abc</span> <span style="color:yellow">555</span> <p style="color: rgb(127,127,127);">Please email me at <span style="color:yellow">gogogo@mail.com</span> </p>&nbsp;</p>
<p><img style="float:none;height: 200px;margin-top : 3%" src="/image/showWorkOrderImg?fileName=123456.png" alt="undefined"/></p>
<span style="color:yellow">abc</span>
```

## Syntax

``` javascript

/* @params 
*   string : startTag, endTag, what, where
*   boolean : caseSensitive (not necessaray, default : false)
*/
TagAroundTextUpdater.insertByWhat(startTag, endTag, what, where, caseSensitive);

/* @params 
*   string : startTag, endTag, type (only 'integer', 'email' available for the current version), where
*/
TagAroundTextUpdater.insertByType(startTag, endTag, type, where);

```
